Name:		orthanc
Version:	0.5.2
Release:	1%{?dist}
Summary:	RESTful DICOM server for healthcare and medical research

License:	GPLv3 with exceptions
URL:		https://code.google.com/p/orthanc/
Source0:	https://orthanc.googlecode.com/files/Orthanc-%{version}.tar.gz
Source1:	orthanc.json
Source2:	orthanc.service

# This patch fixes a problem with in-place builds that are currently
# not supported by the CMake script of Orthanc ("UnitTests" is at the
# same time the name of a source directory and of a generated
# executable).
Patch1:		orthanc-0.5.2-cmake.patch

# This patch fixes a CMake error when dynamically linking against Lua
Patch2:		orthanc-0.5.2-lua-cmake.patch

# The two following patches fix a problem in path resolution
Patch3:		orthanc-0.5.2-main.patch
Patch4:		orthanc-0.5.2-initialization.patch

BuildRequires:	cmake >= 2.8.0
BuildRequires:	boost-devel
BuildRequires:	curl-devel
BuildRequires:	dcmtk-devel
BuildRequires:	glog-devel
BuildRequires:	gtest-devel
BuildRequires:	help2man
BuildRequires:	libpng-devel
BuildRequires:	libsqlite3x-devel
BuildRequires:	libuuid-devel
BuildRequires:	mongoose-devel
BuildRequires:	openssl-devel
BuildRequires:	python
BuildRequires:	jsoncpp-devel
BuildRequires:	lua-devel >= 5.1.0

# The following line is required to add the "orthanc" user and group
Requires(pre): shadow-utils

# The following lines are required to install the Systemd service
# https://fedoraproject.org/wiki/Packaging:ScriptletSnippets?rd=Packaging/ScriptletSnippets#Macroized_scriptlets_.28Fedora_18.2B.29
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd


%description
Orthanc aims at providing a simple, yet powerful standalone DICOM
server. Orthanc can turn any computer running Windows or Linux into a
DICOM store (in other words, a mini-PACS system). Its architecture is
lightweight, meaning that no complex database administration is
required, nor the installation of third-party dependencies.

What makes Orthanc unique is the fact that it provides a RESTful
API. Thanks to this major feature, it is possible to drive Orthanc
from any computer language. The DICOM tags of the stored medical
images can be downloaded in the JSON file format. Furthermore,
standard PNG images can be generated on-the-fly from the DICOM
instances by Orthanc.

Orthanc lets its users focus on the content of the DICOM files,
hiding the complexity of the DICOM format and of the DICOM protocol.


%prep
%setup -q -n Orthanc-%{version}
%patch1
%patch2
%patch3
%patch4

# Copy the configuration file and the Systemd Service for the Orthanc server
cp -p %SOURCE1 orthanc.json
cp -p %SOURCE2 orthanc.service


%build
%cmake	-DSTATIC_BUILD:BOOL=OFF \
	-DSTANDALONE_BUILD:BOOL=ON \
	-DUSE_DYNAMIC_GOOGLE_LOG:BOOL=ON \
	-DUSE_DYNAMIC_JSONCPP:BOOL=ON \
	-DUSE_DYNAMIC_MONGOOSE:BOOL=ON \
	-DUSE_DYNAMIC_LUA:BOOL=ON \
	-DCMAKE_BUILD_TYPE=Release \
	.

make %{?_smp_mflags}

# Generate the man page
help2man ./Orthanc -N -n "Lightweight, RESTful DICOM server for healthcare and medical research" > Orthanc.1


%check
# Execute the unit tests
./UnitTestsExecutable


%install
make install DESTDIR=%{buildroot}

install -m 755 -d %{buildroot}%{_mandir}/man1
cp Orthanc.1 %{buildroot}%{_mandir}/man1

install -m 755 -d %{buildroot}%{_sysconfdir}/orthanc
cp orthanc.json %{buildroot}%{_sysconfdir}/orthanc

install -m 755 -d %{buildroot}%{_unitdir}
cp orthanc.service %{buildroot}%{_unitdir}

install -m 755 -d %{buildroot}%{_sharedstatedir}/orthanc/db-v3


%files
%doc NEWS README THANKS COPYING
%{_mandir}/man1/*.1*
%{_sbindir}/*
%{_unitdir}/orthanc.service

%dir %{_sysconfdir}/orthanc
%config(noreplace) %{_sysconfdir}/orthanc/orthanc.json
%dir %attr(0755, orthanc, orthanc) %{_sharedstatedir}/orthanc
%dir %attr(0755, orthanc, orthanc) %{_sharedstatedir}/orthanc/db-v3



# Installation of the Systemd Orthanc service
# https://fedoraproject.org/wiki/Packaging:ScriptletSnippets#Systemd
%post
%systemd_post orthanc.service

%preun
%systemd_preun orthanc.service

%postun
%systemd_postun_with_restart orthanc.service


%pre
# http://fedoraproject.org/wiki/Packaging%3aUsersAndGroups
# "We never remove users or groups created by packages"

getent group orthanc >/dev/null || groupadd -r orthanc
getent passwd orthanc >/dev/null || \
    useradd -r -g orthanc -G orthanc -d %{_sharedstatedir}/orthanc -s /sbin/nologin \
    -c "User account that holds information for Orthanc" orthanc
exit 0


%changelog
* Wed May  8 2013 Sebastien Jodogne <s.jodogne@gmail.com> 0.5.2-1
- New upstream version

* Thu Apr 17 2013 Sebastien Jodogne <s.jodogne@gmail.com> 0.5.1-1
- New upstream version

* Thu Apr 04 2013 Sebastien Jodogne <s.jodogne@gmail.com> 0.5.0-1
- New upstream version

* Wed Dec 19 2012 Sebastien Jodogne <s.jodogne@gmail.com> 0.4.0-5
- Fixes according to reviews

* Wed Dec 19 2012 Sebastien Jodogne <s.jodogne@gmail.com> 0.4.0-4
- Dynamic linking against mongoose-lib

* Wed Dec 19 2012 Sebastien Jodogne <s.jodogne@gmail.com> 0.4.0-3
- Improvements to the packaging

* Tue Dec 18 2012 Sebastien Jodogne <s.jodogne@gmail.com> 0.4.0-2
- Improvements to the packaging

* Mon Dec 17 2012 Sebastien Jodogne <s.jodogne@gmail.com> 0.4.0-1
- Initial RPM Release
